@@ -6,6 +6,7 @@ use warnings;
 use DBI;
 use File::Temp ();
 
+use Fey 0.10;
 use Fey::Column;
 use Fey::FK;
 use Fey::Schema;
@@ -21,7 +22,7 @@ BEGIN
 
 use Test::MockObject;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 
 sub mock_test_schema
@@ -338,7 +339,7 @@ sub _mock_primary_key_info
 
     my $x = 1;
     my @pk;
-    for my $pk ( $table->primary_key() )
+    for my $pk ( @{ $table->primary_key() } )
     {
         push @pk,
             { COLUMN_NAME => $pk->name(),
@@ -357,7 +358,7 @@ sub _mock_statistics_info
     my $table = $self->{__schema__}->table($table_name);
 
     my @ck;
-    for my $ck ( $table->candidate_keys() )
+    for my $ck ( @{ $table->candidate_keys() } )
     {
         my $x = 1;
         for my $col ( @{ $ck } )
@@ -383,7 +384,7 @@ sub _mock_foreign_key_info
     return unless $table;
 
     my @fk;
-    my %pk = map { $_->name() => 1 } $table->primary_key();
+    my %pk = map { $_->name() => 1 } @{ $table->primary_key() };
 
     for my $fk ( $self->{__schema__}->foreign_keys_for_table($table) )
     {
